/*
 *  ngtk/c/ngtk_winstack.c
 *
 *  Copyright (C) 1998, 1999 Gabriel Fort <gabx@tfz.net>
 *
 */

/*----------------------------------------------------------------------------

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the 
    Free Software Foundation, Inc., 59 Temple Place - Suite 330, 
    Boston, MA  02111-1307  USA.

----------------------------------------------------------------------------*/
#include <ngtk/ngtk.h>
#include <signal.h>

void ngtk_resize_win(ngtk_win_t *resive_win, int height, int width)
{

}

void ngtk_move_win(ngtk_win_t *move_win, int top, int left)
{
    move_panel(move_win->pan, top, left);

	if (move_win->shadow_flag)
	    move_panel(move_win->shadow_pan, top+1, left+1);

    update_panels();
    doupdate();
}

void ngtk_pull_win(ngtk_win_t *pull_win)
{
    if (pull_win->shadow_flag)
        top_panel(pull_win->shadow_pan);
    top_panel(pull_win->pan);

    update_panels();
    prev_curs = curs_set(pull_win->cursor_flag);
	doupdate();
}

ngtk_win_t *ngtk_push_win(int height, int width, int top, int left, int cpair,
                   		  int attr, int echo_cursor, int shadow)
{
	ngtk_win_t *ret_win = (ngtk_win_t *)malloc(sizeof(ngtk_win_t));

	ret_win->prev = prev_buffer;

    if (((height + top+shadow) > LINES) || ((width + left+shadow) > COLS)) {
        ngtk_errbox("Window out of bounds");
        ngtk_stop_display();
		exit(-1);
    }

    ret_win->cursor_flag = echo_cursor;
    ret_win->shadow_flag = shadow;

    ret_win->win = newwin(height, width, top, left);
    if (shadow) {
        ret_win->shadow = newwin(height, width, top+1, left+1);
        ret_win->shadow_pan = new_panel(ret_win->shadow);
        wattrset(ret_win->shadow, COLOR_PAIR(0) | A_NORMAL);
    }
    ret_win->pan = new_panel(ret_win->win);
    update_panels();

    prev_curs = curs_set(ret_win->cursor_flag);
    wattrset(ret_win->win, COLOR_PAIR(cpair) | attr);
    ret_win->cpair = cpair;
    ret_win->attr = attr;

    wrefresh(ret_win->win);

	prev_buffer = ret_win;
	return(ret_win);
}

void ngtk_pop_win(ngtk_win_t *kill_win)
{
	int echo = prev_curs;

    del_panel(kill_win->pan);
    if (kill_win->shadow_flag)
        del_panel(kill_win->shadow_pan);
    update_panels();

    delwin(kill_win->win);
    if (kill_win->shadow_flag)
        delwin(kill_win->shadow);

	free(kill_win);
    doupdate();

	prev_curs = curs_set(echo);
/* FIXME: The cursor visibility state isn't well restored after a pop_win() */
}

